@@ -4,7 +4,7 @@ class Protocol(object):
     """A Protocol encapsulates a single aspect of ok.py functionality."""
     name = None # Override in sub-class.
 
-    def __init__(self, cmd_line_args, assignment, logger):
+    def __init__(self, cmd_line_args, assignment, output_logger, log=None):
         """Constructor.
 
         PARAMETERS:
@@ -14,11 +14,13 @@ class Protocol(object):
         logger        -- OutputLogger; used to control output
                          destination, as well as capturing output from
                          an autograder session.
+        log           -- Logger; used for printing debugging messages.
         """
         self.args = cmd_line_args
         self.assignment = assignment
-        self.logger = logger
+        self.logger = output_logger
         self.analytics = {}
+        self.log = log
 
     def on_start(self):
         """Called when ok.py starts. Returns an object to be sent to server."""
